BiometricPromptInfo class

Configuration for the biometric authentication prompt.

Constructors

BiometricPromptInfo({String? title, String? subtitle, String? description, String? negativeButtonText})
Creates a new BiometricPromptInfo.
const

Properties

description → String?
The description of the prompt (Android only).
final
hashCode → int
The hash code for this object.
no setterinherited
negativeButtonText → String?
The text for the negative button (e.g., "Cancel") (Android only).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → String?
The subtitle of the prompt (Android only).
final
title → String?
The title of the prompt (Android only).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited